@@ -49,6 +49,11 @@ return [
 			'url' => '/box/{mailboxId}/thread/{id}',
 			'verb' => 'GET'
 		],
+		[
+			'name' => 'page#draft',
+			'url' => '/box/{mailboxId}/thread/new/{draftId}',
+			'verb' => 'GET'
+		],
 		[
 			'name' => 'page#index',
 			'url' => '/',
@@ -59,6 +64,11 @@ return [
 			'url' => '/compose',
 			'verb' => 'GET'
 		],
+		[
+			'name' => 'page#mailto',
+			'url' => '/mailto',
+			'verb' => 'GET'
+		],
 		[
 			'name' => 'accounts#send',
 			'url' => '/api/accounts/{id}/send',
