@@ -29,7 +29,9 @@ OC.L10N.register(
     "Send" : "Unviar",
     "Choose a file to add as attachment" : "Escueyi un ficheru p'amestalu como axuntu",
     "Select" : "Esbillar",
+    "Move" : "Mover",
     "Delete" : "Desaniciar",
+    "Choose" : "Escoyer",
     "Important" : "Importante",
     "Favorites" : "Favorites",
     "Other" : "Otru",
