@@ -13,7 +13,9 @@ OC.L10N.register(
     "Send" : "পাঠাও",
     "Choose a file to add as attachment" : "সংযুক্তি দেয়ার জন্য একটি ফাইল নির্বাচন করুন",
     "Select" : "সিলেক্ট",
+    "Move" : "Move",
     "Delete" : "মুছে",
+    "Choose" : "বেছে নিন",
     "Important" : "গুরুত্বপূর্ণ",
     "Favorites" : "প্রিয়জন",
     "Other" : "অন্যান্য",
