@@ -16,7 +16,11 @@ OC.L10N.register(
     "Send" : "Kas",
     "Unselect" : "Dizibab",
     "Select" : "Dibab",
+    "Move" : "Diplasañ",
     "Delete" : "Dilemel",
+    "Choose target folder" : "Dibab an teuliad moned",
+    "No more subfolders in here" : "N'ez eus ket isteuliadoù all amañ",
+    "Choose" : "Dibab",
     "Important info" : "Titouroù pouezus",
     "Favorites" : "Pennrolloù",
     "Other" : "All",
