@@ -50,9 +50,11 @@ OC.L10N.register(
     "Mark unread" : "Nodi heb ei ddarllen",
     "Mark read" : "Marcio wedi'i ddarllen",
     "Select" : "Select",
+    "Move" : "Symud",
     "Delete" : "Dileu",
     "Report this bug" : "Cofnodi'r gwall",
     "Loading messages" : "Llwytho negeseuon",
+    "Choose" : "Dewisa",
     "Favorites" : "Ffefrynnau",
     "Other" : "Arall",
     "Import into calendar" : "Mewnforio i'r calendr",
