@@ -73,8 +73,12 @@ OC.L10N.register(
     "Mark read" : "Marker som læst",
     "Unselect" : "Fravælg",
     "Select" : "Vælg",
+    "Move" : "Flyt",
     "Delete" : "Slet",
     "Loading messages" : "Henter beskedder",
+    "Choose target folder" : "Vælg destinationsmappe",
+    "No more subfolders in here" : "Her er ikke flere undermapper",
+    "Choose" : "Vælg",
     "Important" : "Vigtigt",
     "Favorites" : "Favoritter",
     "Other" : "Andet",
