@@ -33,7 +33,11 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
     "Mark read" : "Marcar como leído",
     "Select" : "Seleccionar",
+    "Move" : "Mover",
     "Delete" : "Borrar",
+    "Choose target folder" : "Elegir carpeta destino",
+    "No more subfolders in here" : "No más subcarpetas aquí",
+    "Choose" : "Elige",
     "Important" : "Importante",
     "Favorites" : "Favoritos",
     "Other" : "Otro",
