@@ -1,10 +1,10 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Correo",
     "Auto detect failed. Please use manual mode." : "Se presentó una falla en la auto detección. Por favor usa el modo manual.",
     "Updating account failed: " : "Se presentó una falla al actualizar la cuenta",
     "Creating account failed: " : "Se presentó una falla al crear la cuenta:",
+    "Mail" : "Correo",
     "Name" : "Nombre",
     "Mail Address" : "Dirección de Correo",
     "Password" : "Contraseña",
@@ -23,7 +23,6 @@ OC.L10N.register(
     "Connect" : "Conectar",
     "Add mail account" : "Agregar cuenta de correo",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
-    "Keyboard shortcuts" : "Atajos del teclado",
     "Select account" : "Selecciona la cuenta",
     "Subject" : "Asunto",
     "Upload attachment" : "Cargar adjunto",
@@ -36,27 +35,41 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "No messages in this folder" : "No hay mensajes en esta carpeta",
     "Mark read" : "Marcar como leído",
+    "Select" : "Seleccionar",
+    "Move" : "Mover",
     "Delete" : "Borrar",
-    "Reply" : "Responder",
-    "Forward" : "Adelante",
-    "Could not load your message" : "No fue posible cargar tu mensaje",
+    "Choose" : "Seleccionar",
+    "Important" : "Importante",
+    "Favorites" : "Favoritos",
+    "Other" : "Otro",
     "Import into calendar" : "Importar al calendario",
     "Download attachment" : "Descargar adjunto",
     "Save to Files" : "Guardar a Archivos",
+    "Unnamed" : "Sin nombre",
     "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
     "Save all to Files" : "Guardar todo a Archivos",
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
+    "Show images from this sender" : "Mostrar imagenes de este remitente",
     "New message" : "Mensaje nuevo",
     "Settings" : "Configuraciones ",
-    "Delete account" : "Borrar cuenta",
+    "Quota" : "Cuota",
+    "Saving" : "Guardando",
+    "Remove account" : "Eliminar cuenta",
+    "Cancel" : "Cancelar",
     "Show all folders" : "Mostrar todas las carpetas",
     "Collapse folders" : "Compactar carpetas",
     "Mark all as read" : "Marcar todos como leídos",
+    "Clear cache" : "Borrar el caché",
+    "Delete folder" : "Borrar carpeta",
     "Signature" : "Firma",
+    "Reply" : "Responder",
+    "Forward" : "Adelante",
     "General" : "General",
     "User" : "Usuario",
     "Host" : "Servidor",
     "Port" : "Puerto",
+    "Keyboard shortcut" : "Atajo del teclado",
+    "Keyboard shortcuts" : "Atajos del teclado",
     "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
     "Compose new message" : "Escribir mensaje nuevo",
     "Newer message" : "Mensaje más nuevo",
@@ -66,11 +79,20 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Refresh" : "Actualizar",
     "Connect your mail account" : "Conecta tu cuenta de correo",
+    "All" : "Todos",
+    "Archive" : "Archivar",
+    "Drafts" : "Borradores",
+    "All inboxes" : "Todos los buzones de entrada",
+    "Inbox" : "Buzón de entrada",
+    "Junk" : "Basura",
+    "Sent" : "Enviado",
+    "Trash" : "Basura",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos \nde {from}"],
     "Nextcloud Mail" : "Correo Nextcloud",
     "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
+    "Could not load your message" : "No fue posible cargar tu mensaje",
     "Could not load the desired message" : "No fue posible cargar el mensaje deseado",
     "Could not load the message" : "No fue posible cargar el mensaje",
     "Error loading message" : "Se presentó un error al cargar el mensaje",
