@@ -1,9 +1,9 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Correo",
     "Auto detect failed. Please use manual mode." : "Se presentó una falla en la auto detección. Por favor usa el modo manual.",
     "Creating account failed: " : "Se presentó una falla al crear la cuenta:",
+    "Mail" : "Correo",
     "Name" : "Nombre",
     "Mail Address" : "Dirección de Correo",
     "Password" : "Contraseña",
@@ -22,7 +22,6 @@ OC.L10N.register(
     "Connect" : "Conectar",
     "Add mail account" : "Agregar cuenta de correo",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
-    "Keyboard shortcuts" : "Atajos del teclado",
     "Select account" : "Selecciona la cuenta",
     "Subject" : "Asunto",
     "Upload attachment" : "Cargar adjunto",
@@ -33,18 +32,14 @@ OC.L10N.register(
     "Message sent!" : "¡Mensaje enviado!",
     "Send" : "Enviar",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
-    "Unfavorite" : "Quitar favorito",
-    "Favorite" : "Hacer favorito",
     "Mark read" : "Marcar como leído",
     "Select" : "Seleccionar",
+    "Move" : "Mover",
     "Delete" : "Borrar",
+    "Choose" : "Seleccionar",
     "Important" : "Importante",
     "Favorites" : "Favoritos",
     "Other" : "Otro",
-    "to" : "para",
-    "cc" : "cc",
-    "Reply" : "Responder",
-    "Forward" : "Adelante",
     "Import into calendar" : "Importar al calendario",
     "Download attachment" : "Descargar adjunto",
     "Save to Files" : "Guardar a Archivos",
@@ -56,17 +51,23 @@ OC.L10N.register(
     "New message" : "Mensaje nuevo",
     "Settings" : "Configuraciones ",
     "Quota" : "Cuota",
+    "Saving" : "Guardando",
     "Remove account" : "Eliminar cuenta",
     "Cancel" : "Cancelar",
     "Show all folders" : "Mostrar todas las carpetas",
     "Collapse folders" : "Compactar carpetas",
     "Mark all as read" : "Marcar todos como leídos",
     "Clear cache" : "Borrar el caché",
+    "Delete folder" : "Borrar carpeta",
     "Signature" : "Firma",
+    "Reply" : "Responder",
+    "Forward" : "Adelante",
     "General" : "General",
     "User" : "Ususario",
     "Host" : "Servidor",
     "Port" : "Puerto",
+    "Keyboard shortcut" : "Atajo del teclado",
+    "Keyboard shortcuts" : "Atajos del teclado",
     "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
     "Compose new message" : "Escribir mensaje nuevo",
     "Newer message" : "Mensaje más nuevo",
