@@ -29,7 +29,9 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Vali fail, mida manustada",
     "Mark read" : "Märgi loetuks",
     "Select" : "Vali",
+    "Move" : "Liiguta",
     "Delete" : "Kustuta",
+    "Choose" : "Vali",
     "Important" : "Tähtis",
     "Favorites" : "Lemmikud",
     "Other" : "Muu",
