@@ -81,17 +81,17 @@ OC.L10N.register(
     "Mark as spam" : "Merkitse roskapostiksi",
     "Unselect" : "Poista valinta",
     "Select" : "Valitse",
+    "Move" : "Siirrä",
     "Delete" : "Poista",
     "Blind copy recipients only" : "Vain piilokopion vastaanottajat",
-    "Unfavorite " : "Ei suosikki",
-    "Favorite " : "Suosikki",
-    "Unselect " : "Ei valintaa",
-    "Delete " : "Poista",
     "Load more" : "Lataa lisää",
     "Report this bug" : "Ilmoita viasta",
     "Could not open mailbox" : "Postilaatikkoa ei voitu avata",
     "Loading messages" : "Ladataan viestejä",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Viestejäsi indeksoidaan. Tämä saattaa kestää hetken varsinkin suurikokoisissa postilaatikoissa.",
+    "Choose target folder" : "Valitse kohdekansio",
+    "No more subfolders in here" : "Täällä ei ole enempää alikansioita",
+    "Choose" : "Valitse",
     "Important" : "Tärkeä",
     "Favorites" : "Suosikit",
     "Other" : "Muu",
