@@ -73,10 +73,14 @@ OC.L10N.register(
     "Mark read" : "Olvasottnak jelöl",
     "Unselect" : "Kiválasztás megszüntetése",
     "Select" : "Kijelölés",
+    "Move" : "Áthelyezés",
     "Delete" : "Törlés",
     "Report this bug" : "A hiba bejelentése",
     "Could not open mailbox" : "Mailbox nem nyitható meg",
     "Loading messages" : "Üzenetek betöltése",
+    "Choose target folder" : "Válasszon célmappát",
+    "No more subfolders in here" : "Itt nincsenek almappák",
+    "Choose" : "Válasszon",
     "Important" : "Fontos",
     "Favorites" : "Kedvencek",
     "Other" : "Egyéb",
