@@ -22,7 +22,11 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
     "Unselect" : "Batal pilih",
     "Select" : "Pilih",
+    "Move" : "Pindah",
     "Delete" : "Hapus",
+    "Choose target folder" : "Pilih folder target",
+    "No more subfolders in here" : "Tidak ada lagi subfolder disini",
+    "Choose" : "Pilih",
     "Important" : "Penting",
     "Favorites" : "Disukai",
     "Other" : "Lainnya",
