@@ -35,7 +35,9 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
     "Mark read" : "მონიშნეთ წაკითხულად",
     "Select" : "არჩევა",
+    "Move" : "გადატანა",
     "Delete" : "გაუქმება",
+    "Choose" : "აირჩიეთ",
     "Important" : "აუცილებელი",
     "Favorites" : "რჩეულები",
     "Other" : "სხვა",
