@@ -11,7 +11,9 @@ OC.L10N.register(
     "Sending …" : "កំពុង​ផ្ញើរ...",
     "Send" : "ផ្ញើ",
     "Select" : "Select",
+    "Move" : "Move",
     "Delete" : "លុប",
+    "Choose" : "ជ្រើស",
     "Important" : "សំខាន់",
     "Favorites" : "Favorites",
     "Other" : "ផ្សេងៗ",
