@@ -9,7 +9,9 @@ OC.L10N.register(
     "Save" : "﻿ಉಳಿಸಿ",
     "Send" : "﻿ಕಳುಹಿಸಿ",
     "Select" : "Select",
+    "Move" : "Move",
     "Delete" : "﻿ಅಳಿಸಿ",
+    "Choose" : "﻿ಆಯ್ಕೆ",
     "Favorites" : "ಅಚ್ಚುಮೆಚ್ಚಿನ",
     "Other" : "﻿ಇತರೆ",
     "Settings" : "ಆಯ್ಕೆ",
