@@ -79,16 +79,15 @@ OC.L10N.register(
     "Mark as spam" : "스팸 신고",
     "Unselect" : "선택 해제",
     "Select" : "선택",
+    "Move" : "이동",
     "Delete" : "삭제",
-    "Mark " : "표시",
-    "Unfavorite " : "즐겨찾기 해제",
-    "Favorite " : "즐겨찾기",
-    "Unselect " : "선택 해제",
-    "Delete " : "삭제",
     "Load more" : "더 불러오기",
     "Report this bug" : "이 오류 보고",
     "Could not open mailbox" : "메일함을 열 수 없음",
     "Loading messages" : "메세지를 불러오는 중",
+    "Choose target folder" : "폴더 선택",
+    "No more subfolders in here" : "더 이상의 하위 폴더 없음",
+    "Choose" : "선택",
     "Important" : "중요",
     "Important info" : "중요 정보",
     "Favorites" : "즐겨찾기",
