@@ -11,7 +11,9 @@ OC.L10N.register(
     "Go back" : "Zeréckgoen",
     "Send" : "Schécken",
     "Select" : "Select",
+    "Move" : "Verschieben",
     "Delete" : "Läschen",
+    "Choose" : "Auswielen",
     "Important" : "Wichteg",
     "Favorites" : "Favoriten",
     "Other" : "Aner",
