@@ -43,7 +43,10 @@ OC.L10N.register(
     "No messages in this folder" : "Šajā mapē nav neviens ziņojums",
     "Unselect" : "Noņemt atlasi",
     "Select" : "Atzīmēt",
+    "Move" : "Pārvietot",
     "Delete" : "Dzēst",
+    "No more subfolders in here" : "Šeit nav vairāk apakšmapju",
+    "Choose" : "Izvēlies",
     "Important" : "Svarīgi",
     "Favorites" : "Favorīti",
     "Other" : "Cits",
