@@ -51,9 +51,13 @@ OC.L10N.register(
     "Mark read" : "Marker som lest",
     "Unselect" : "Velg bort",
     "Select" : "Velg",
+    "Move" : "Flytt",
     "Delete" : "Slett",
     "Report this bug" : "Rapporter denne feilen",
     "Loading messages" : "Henter meldinger",
+    "Choose target folder" : "Velg målmappe",
+    "No more subfolders in here" : "Ingen flere mapper her",
+    "Choose" : "Velg",
     "Important" : "Viktig",
     "Favorites" : "Favoritter",
     "Other" : "Annet",
