@@ -22,7 +22,11 @@ OC.L10N.register(
     "Message sent!" : "Mesaj trimis!",
     "Send" : "Trimite",
     "Select" : "Select",
+    "Move" : "Mută",
     "Delete" : "Șterge",
+    "Choose target folder" : "Alege directorul destinație",
+    "No more subfolders in here" : "Nu mai sunt subdirectoare aici",
+    "Choose" : "Alege",
     "Important" : "Important",
     "Favorites" : "Favorite",
     "Other" : "Altele",
