@@ -33,7 +33,9 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
     "Mark read" : "Shëno të lexuar",
     "Select" : "Zgjidhni",
+    "Move" : "Zhvendos",
     "Delete" : "Fshij",
+    "Choose" : "Zgjidhni",
     "Important" : "E rëndësishme",
     "Favorites" : "Favorites",
     "Other" : "Tjetër",
