@@ -10,7 +10,9 @@ OC.L10N.register(
     "Select account" : "Označite nalog",
     "Send" : "Pošalji",
     "Select" : "Obeleži",
+    "Move" : "Premesti",
     "Delete" : "Delete",
+    "Choose" : "Odaberi",
     "Favorites" : "Omiljene",
     "Other" : "Ostali",
     "Attachments" : "Prilozi",
