@@ -7,7 +7,9 @@ OC.L10N.register(
     "Save" : "சேமிக்க ",
     "Connect" : "இணைக்க",
     "Select" : "Select",
+    "Move" : "Move",
     "Delete" : "நீக்குக",
+    "Choose" : "தெரிவுசெய்க ",
     "Important" : "முக்கியமான ",
     "Favorites" : "விருப்பங்கள்",
     "Other" : "மற்றவை",
