@@ -16,7 +16,9 @@ OC.L10N.register(
     "Send" : "ส่ง",
     "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
     "Select" : "Select",
+    "Move" : "Move",
     "Delete" : "ลบ",
+    "Choose" : "เลือก",
     "Important" : "สำคัญ",
     "Favorites" : "รายการโปรด",
     "Other" : "อื่นๆ",
