@@ -81,18 +81,17 @@ OC.L10N.register(
     "Mark as spam" : "Позначити як спам",
     "Unselect" : "Зняти виділення",
     "Select" : "Вибрати",
+    "Move" : "Перемістити",
     "Delete" : "Вилучити",
     "Blind copy recipients only" : "Лише отримувачі у прихованій копії",
-    "Mark " : "Позначити",
-    "Unfavorite " : "Не улюблене",
-    "Favorite " : "Улюблені",
-    "Unselect " : "Зняти позначки",
-    "Delete " : "Вилучити",
     "Load more" : "Більше",
     "Report this bug" : "Повідомити про помилку",
     "Could not open mailbox" : "Неможливо відкрити поштову скриньку",
     "Loading messages" : "Завантаження повідомлень",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Індексування повідомлень. Ця дія може забрати більше часу для поштових скриньок з великим обсягом повідомлень.",
+    "Choose target folder" : "Виберіть теку призначення",
+    "No more subfolders in here" : "Тут більше немає підтек",
+    "Choose" : "Вибрати",
     "Important" : "Важливі",
     "Favorites" : "Улюблене",
     "Other" : "Інші",
