@@ -7,7 +7,9 @@ OC.L10N.register(
     "Connect" : "منسلک",
     "Send" : "بھجیں",
     "Select" : "Select",
+    "Move" : "Move",
     "Delete" : "حذف کریں",
+    "Choose" : "منتخب کریں",
     "Important" : "اہم",
     "Favorites" : "Favorites",
     "Other" : "دیگر",
