@@ -12,7 +12,9 @@ OC.L10N.register(
     "Go back" : "Quay lại",
     "Send" : "Gởi",
     "Select" : "Select",
+    "Move" : "Dịch chuyển",
     "Delete" : "Xóa",
+    "Choose" : "Chọn",
     "Important" : "Quan trọng",
     "Favorites" : "Ưa thích",
     "Other" : "Khác",
