@@ -5,10 +5,16 @@ OC.L10N.register(
     "Updating account failed: " : "更新账号失败：",
     "Creating account failed: " : "创建账号失败：",
     "Embedded message %s" : "嵌入式消息 %s",
+    "Important mail" : "重要邮件",
     "Mails" : "邮件",
     "Mail" : "邮件",
     "💌 A mail app for Nextcloud" : "💌 Nextcloud 上的一款邮件应用",
     "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](http://horde.org) libraries.\n- **📬 Want to host your own mail server?** We don’t have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 上的一款邮件应用**\n\n- **🚀 与其他 Nextcloud 应用集成！** 当前已集成联系人、日历和文件应用 —— 后续还有更多。\n- **📥 多个邮箱账号！** 个人和公司账号？没问题，还有好用的统一收件箱。可连接任何 IMAP 账号。\n- **🔒 收发加密邮件！** 使用超棒的 [Mailvelope](https://mailvelope.com) 浏览器扩展。\n- **🙈 我们没有重复造轮子！** 基于超棒的 [Horde](http://horde.org) 软件库。\n- **📬 想托管您自己的邮件服务器？** 我们不需要重新实现这个功能，因为你们可以搭建 [Mail-in-a-Box](https://mailinabox.email)！",
+    "Defaults" : "默认",
+    "Here you can select where Nextcloud Mail stores your drafts as well as sent and deleted messages." : "在这里，您可以选择 Nextcloud 邮件保存您的草稿以及已发送和删除的邮件的位置。",
+    "Draft messages are saved to:" : "草稿邮件保存在：",
+    "Sent messages are saved to:" : "已发送邮件保存在：",
+    "Deleted messages are moved to:" : "已删除邮件将被移至：",
     "Auto" : "自动",
     "Name" : "姓名",
     "Mail Address" : "邮箱",
@@ -50,6 +56,7 @@ OC.L10N.register(
     "This message came from a noreply address so your reply will probably not be read." : "标记的消息来自一个无法回复的地址，您的回复可能不会被阅读。",
     "The following recipients do not have a PGP key: {recipients}." : "以下收件人没有 PGP 密钥：{recipients}。",
     "Write message …" : "编写消息...",
+    "Can not save draft because this account does not have a drafts mailbox configured." : "无法保存草稿，因为该账号没有配置草稿邮箱。",
     "Saving draft …" : "正在保存草稿 …",
     "Draft saved" : "草稿已保存",
     "Upload attachment" : "上传附件",
@@ -68,6 +75,7 @@ OC.L10N.register(
     "Send" : "发送",
     "Encrypt and send" : "加密并发送",
     "Send unencrypted" : "不加密发送",
+    "No sent mailbox configured. Please pick one in the account settings." : "没有配置发送邮箱。请在账号设置中选择一个。",
     "Uploading {percent}% …" : "正在上传 {percent}% …",
     "Choose a file to add as attachment" : "选择文件添加为附件",
     "Choose a file to share as a link" : "选择要共享的文件作为链接",
@@ -80,27 +88,40 @@ OC.L10N.register(
     "Draft: " : "草稿: ",
     "Mark unimportant" : "标记为不重要",
     "Mark important" : "标记为重要",
+    "Mark unfavorite" : "取消收藏",
+    "Mark favorite" : "收藏",
     "Mark unread" : "标记为未读",
     "Mark read" : "标记为已读",
     "Mark not spam" : "标记为非垃圾邮件",
     "Mark as spam" : "标记为垃圾邮件",
     "Unselect" : "取消选择",
     "Select" : "选择",
+    "Move" : "移动",
+    "Edit as new message" : "编辑为新消息",
     "Delete" : "删除",
     "Blind copy recipients only" : "仅向收件人发送无信头副本",
-    "Mark " : "标记",
-    "Unfavorite " : "取消收藏",
-    "Favorite " : "收藏",
-    "Unselect " : "取消选择",
-    "Delete " : "删除",
+    "No trash mailbox configured" : "没有配置垃圾邮箱",
+    "Could not delete message" : "无法删除消息",
+    "Mark {number} unread" : "将 {number} 标记为未读",
+    "Mark {number} read" : "将 {number} 标记为已读",
+    "Unfavorite {number}" : "取消收藏 {number}",
+    "Favorite {number}" : "收藏 {number}",
+    "Unselect {number}" : "取消选择 {number}",
+    "Move {number}" : "移动 {number}",
+    "Delete {number}" : "删除 {number}",
     "Load more" : "加载更多",
     "Report this bug" : "报告此问题",
     "Could not open mailbox" : "无法打开邮箱",
     "Loading messages" : "正在加载消息",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "正在为您的消息建立索引。 对于较大的邮箱，这可能需要更长的时间。",
+    "Choose target folder" : "选择目标文件夹",
+    "No more subfolders in here" : "没有更多的子文件夹",
+    "Choose" : "选择",
     "Important" : "重要",
+    "Important info" : "重要信息",
     "Favorites" : "收藏",
     "Other" : "其他",
+    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "根据您与哪些消息互动或手动标记重要消息，消息会自动被标记为重要。在开始的时候，您可能需要手动改变重要性来调教系统，但随着时间的推移，它会不断改进。",
     "Attachments" : "附件",
     "Import into calendar" : "导入到日历",
     "Download attachment" : "下载附件",
@@ -113,6 +134,9 @@ OC.L10N.register(
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "此消息已使用 PGP 加密。 安装 Mailvelope 对其进行解密。",
     "The images have been blocked to protect your privacy." : "图片已被禁用，以保护您的隐私。",
     "Show images from this sender" : "显示此发件人的图片",
+    "Message frame" : "消息框",
+    "Quoted text" : "引用文字",
+    "Moving" : "移动",
     "New message" : "新建消息",
     "Settings" : "设置",
     "Quota" : "配额",
@@ -120,11 +144,13 @@ OC.L10N.register(
     "Show only subscribed folders" : "仅显示已订阅的文件夹",
     "Add folder" : "添加文件夹",
     "Saving" : "正在保存",
+    "Move up" : "上移",
     "Move down" : "下移",
     "Remove account" : "移除账号",
     "Loading …" : "正在加载...",
     "Not supported by the server" : "服务器不支持",
     "{usage} of {limit} used" : "已使用{usage} / {limit}",
+    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "{email} 的账号和缓存的电子邮件数据将从 Nextcloud 中删除，但不会从您的电子邮件提供商那里删除。",
     "Remove account {email}" : "移除账号 {email}",
     "Remove {email}" : "移除 {email}",
     "Cancel" : "取消",
@@ -132,13 +158,21 @@ OC.L10N.register(
     "Show all folders" : "显示全部文件夹",
     "Collapse folders" : "折叠文件夹",
     "Mark all as read" : "标记所有为已读",
+    "Mark all messages of this mailbox as read" : "将此邮箱中的所有消息都标记为已读",
     "Add subfolder" : "添加子文件夹",
     "Edit name" : "编辑名称",
     "Clear cache" : "清空缓存",
     "Clear locally cached data, in case there are issues with synchronization." : "万一同步出现问题，请清除本地缓存的数据。",
+    "Subscribed" : "已订阅",
+    "Sync in background" : "后台同步",
     "Delete folder" : "删除文件夹",
+    "The folder and all messages in it will be deleted." : "该文件夹及其中的所有消息将被删除。",
+    "Delete folder {name}" : "删除 {name} 文件夹",
+    "An error occurred, unable to rename the mailbox." : "发生错误，无法重命名邮箱。",
     "_{total} message_::_{total} messages_" : ["{total} 条消息"],
+    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["总共 {total} 封邮件，{unread} 封未读邮件"],
     "Not found" : "没有找到",
+    "Attachments were not copied. Please add them manually." : "附件没有被复制。请手动添加。",
     "Could not load your draft" : "无法加载您的草稿",
     "Could not load original message" : "无法加载初始消息",
     "No message selected" : "没有选择消息",
@@ -146,10 +180,12 @@ OC.L10N.register(
     "A signature is added to the text of new messages and replies." : "签名已加入到 新消息 及 回复消息 的文本中。",
     "Signature …" : "签名...",
     "Save signature" : "保存签名",
+    "Could not load your message thread" : "无法加载您的消息线线程",
     "Reply" : "回复",
     "Reply to sender only" : "只回复发送者",
     "Forward" : "转发",
     "View source" : "查看来源",
+    "Download thread data for debugging" : "下载线程数据以进行调试",
     "Message source" : "消息来源",
     "Import into {calendar}" : "导入到 {calendar}",
     "Event imported into {calendar}" : "事件导入到 {calendar}",
@@ -162,9 +198,11 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "火车从 {depStation} 到 {arrStation}",
     "Mail app" : "邮件应用",
     "The mail app allows users to read mails on their IMAP accounts." : "邮件应用允许用户阅读其 IMAP 账号中的邮件。",
+    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "在这里你可以找到实例范围的设置。用户特定的设置在应用本身里（左下角）。",
     "Email: {email}" : "电子邮件：{email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} 在 {host}:{port} ({ssl} 加密)",
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} 在 {host}:{port} ({ssl} 加密)",
+    "You can configure a template for account settings, from which all users will get an account provisioned from." : "您可以为账号设置配置模板，所有用户都可以从中获取预配置的账号。",
     "Provision an account for every user" : "为每个用户设置一个账号",
     "General" : "常规",
     "Email address" : "Email 地址",
@@ -178,6 +216,8 @@ OC.L10N.register(
     "With the settings above, the app will create account settings in the following way:" : "使用上述设置，该应用将通过以下方式创建账号设置：",
     "Change name" : "更改名称",
     "Mail server" : "邮件服务器",
+    "No message found yet" : "暂无消息",
+    "Set up an account" : "设置一个账号",
     "Keyboard shortcut" : "键盘快捷键",
     "Keyboard shortcuts" : "键盘快捷方式",
     "Speed up your Mail experience with these quick shortcuts." : "利用这些快捷方式使您的邮件使用过程更加迅捷",
