@@ -25,6 +25,8 @@ namespace OCA\Mail\Contracts;
 
 use OCA\Mail\Db\Alias;
 use OCA\Mail\Db\Message;
+use OCA\Mail\Exception\ClientException;
+use OCA\Mail\Exception\SentMailboxNotSetException;
 use OCA\Mail\Exception\ServiceException;
 use OCA\Mail\Model\NewMessageData;
 use OCA\Mail\Model\RepliedMessageData;
@@ -34,17 +36,18 @@ interface IMailTransmission {
 	/**
 	 * Send a new message or reply to an existing one
 	 *
-	 * @param NewMessageData $message
-	 * @param RepliedMessageData|null $reply
+	 * @param NewMessageData $messageData
+	 * @param RepliedMessageData|null $replyData
 	 * @param Alias|null $alias
 	 * @param Message|null $draft
 	 *
+	 * @throws SentMailboxNotSetException
 	 * @throws ServiceException
 	 */
-	public function sendMessage(NewMessageData $message,
-								RepliedMessageData $reply = null,
+	public function sendMessage(NewMessageData $messageData,
+								RepliedMessageData $replyData = null,
 								Alias $alias = null,
-								Message $draft = null);
+								Message $draft = null): void;
 
 	/**
 	 * Save a message draft
@@ -54,6 +57,7 @@ interface IMailTransmission {
 	 *
 	 * @return array
 	 *
+	 * @throws ClientException if no drafts mailbox is configured
 	 * @throws ServiceException
 	 */
 	public function saveDraft(NewMessageData $message, Message $previousDraft = null): array;
