@@ -48,8 +48,8 @@ use OCP\AppFramework\Controller;
 use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\JSONResponse;
 use OCP\IL10N;
-use OCP\ILogger;
 use OCP\IRequest;
+use Psr\Log\LoggerInterface;
 
 class AccountsController extends Controller {
 
@@ -62,7 +62,7 @@ class AccountsController extends Controller {
 	/** @var string */
 	private $currentUserId;
 
-	/** @var ILogger */
+	/** @var LoggerInterface */
 	private $logger;
 
 	/** @var IL10N */
@@ -91,7 +91,7 @@ class AccountsController extends Controller {
 	 * @param AccountService $accountService
 	 * @param GroupsIntegration $groupsIntegration
 	 * @param $UserId
-	 * @param ILogger $logger
+	 * @param LoggerInterface $logger
 	 * @param IL10N $l10n
 	 * @param AliasesService $aliasesService
 	 * @param IMailTransmission $mailTransmission
@@ -104,7 +104,7 @@ class AccountsController extends Controller {
 								   AccountService $accountService,
 								   GroupsIntegration $groupsIntegration,
 								   $UserId,
-								   ILogger $logger,
+								   LoggerInterface $logger,
 								   IL10N $l10n,
 								   AliasesService $aliasesService,
 								   IMailTransmission $mailTransmission,
@@ -234,13 +234,12 @@ class AccountsController extends Controller {
 	public function patchAccount(int $id,
 								 string $editorMode = null,
 								 int $order = null,
-								 bool $showSubscribedOnly = null): JSONResponse {
+								 bool $showSubscribedOnly = null,
+								 int $draftsMailboxId = null,
+								 int $sentMailboxId = null,
+								 int $trashMailboxId = null): JSONResponse {
 		$account = $this->accountService->find($this->currentUserId, $id);
 
-		if ($account === null) {
-			return new JSONResponse(null, Http::STATUS_FORBIDDEN);
-		}
-
 		$dbAccount = $account->getMailAccount();
 		if ($editorMode !== null) {
 			$dbAccount->setEditorMode($editorMode);
@@ -251,6 +250,15 @@ class AccountsController extends Controller {
 		if ($showSubscribedOnly !== null) {
 			$dbAccount->setShowSubscribedOnly($showSubscribedOnly);
 		}
+		if ($draftsMailboxId !== null) {
+			$dbAccount->setDraftsMailboxId($draftsMailboxId);
+		}
+		if ($sentMailboxId !== null) {
+			$dbAccount->setSentMailboxId($sentMailboxId);
+		}
+		if ($trashMailboxId !== null) {
+			$dbAccount->setTrashMailboxId($trashMailboxId);
+		}
 		return new JSONResponse(
 			$this->accountService->save($dbAccount)->toJson()
 		);
@@ -456,7 +464,7 @@ class AccountsController extends Controller {
 			return new JSONResponse([
 				'id' => $this->mailManager->getMessageIdForUid($draftsMailbox, $newUID)
 			]);
-		} catch (ServiceException $ex) {
+		} catch (ClientException|ServiceException $ex) {
 			$this->logger->error('Saving draft failed: ' . $ex->getMessage());
 			throw $ex;
 		}
