@@ -23,6 +23,9 @@ declare(strict_types=1);
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+/**
+ * @template-extends QBMapper<Mailbox>
+ */
 namespace OCA\Mail\Db;
 
 use OCA\Mail\Account;
@@ -138,32 +141,6 @@ class MailboxMapper extends QBMapper {
 		}
 	}
 
-	/**
-	 * @throws DoesNotExistException
-	 */
-	public function findSpecial(Account $account, string $specialUse): Mailbox {
-		$mailboxes = $this->findAll($account);
-
-		// First, let's try to detect by special use attribute
-		foreach ($mailboxes as $mailbox) {
-			$specialUses = json_decode($mailbox->getSpecialUse(), true) ?? [];
-			if (in_array($specialUse, $specialUses, true)) {
-				return $mailbox;
-			}
-		}
-
-		// No luck so far, let's do another round and just guess
-		foreach ($mailboxes as $mailbox) {
-			// TODO: also check localized name
-			if (strtolower($mailbox->getName()) === strtolower($specialUse)) {
-				return $mailbox;
-			}
-		}
-
-		// Give up
-		throw new DoesNotExistException("Special mailbox $specialUse does not exist");
-	}
-
 	/**
 	 * @throws MailboxLockedException
 	 */
@@ -222,10 +199,11 @@ class MailboxMapper extends QBMapper {
 	/**
 	 * @param Mailbox $mailbox
 	 * @param IQueryBuilder $query
+	 * @param int|null $value
 	 *
 	 * @return string
 	 */
-	private function eqOrNull(IQueryBuilder $query, string $column, $value, int $type): string {
+	private function eqOrNull(IQueryBuilder $query, string $column, ?int $value, int $type): string {
 		if ($value === null) {
 			return $query->expr()->isNull($column);
 		}
